@@ -11,7 +11,7 @@ from django.db.models import Q
 from django.core.management import call_command
 
 from .models import WordType,WordToken,Dialog,SegmentType,SegmentToken,Speaker,Category,Underlying
-from .utils import fetch_buckeye_resource,loadFile
+from .utils import fetch_buckeye_resource,fetch_media_resource,loadFile
 
 
 Fillers = set(['uh','um','okay','yes','yeah','oh','heh','yknow','um-huh','uh-uh','uh-huh','uh-hum','mm-hmm'])
