@@ -74,6 +74,10 @@ def fetch_buckeye_resource(uri):
     path = os.path.join(settings.BUCKEYE_ROOT,uri)
     return path
 
+def fetch_media_resource(uri):
+    path = os.path.join(settings.MEDIA_ROOT,uri)
+    return path
+
 
 
 
